@@ -11,7 +11,7 @@ import time
 class KNativeKafkaConsumer(threading.Thread):
     daemon = True    
 
-    def __init__(self,topics:str,groupid):
+    def __init__(self,topics:str,group_id:str):
 
         """
         Initialize a KNativeKafkaConsumer class based on the input params and the environment variables.
@@ -25,7 +25,7 @@ class KNativeKafkaConsumer(threading.Thread):
         self.logger = logging.getLogger()
         self.logger.info("Initializing Kafka Consumer")
         print("Initializing Kafka Consumer")
-        self.group_id = groupid
+        self.group_id = group_id
   
         
         if topics:
@@ -40,6 +40,8 @@ class KNativeKafkaConsumer(threading.Thread):
         self.logger.info(bootstrap_server)
         print(bootstrap_server)
         is_tls_enable=os.getenv('KAFKA_NET_TLS_ENABLE',default='False')
+        self.logger.info(is_tls_enable)
+        print(is_tls_enable)
         if is_tls_enable == 'True':
             self.security_protocol="SSL"
             if 'KAFKA_NET_TLS_CA_CERT' not in os.environ:
@@ -51,16 +53,19 @@ class KNativeKafkaConsumer(threading.Thread):
             self.ssl_cafile=os.environ['KAFKA_NET_TLS_CA_CERT']
             self.ssl_certfile=os.environ['KAFKA_NET_TLS_CERT']
             self.ssl_keyfile=os.environ['KAFKA_NET_TLS_KEY']
+            print("Inside if")
+            self.logger.info("Inside if")
         else:
             self.security_protocol="PLAINTEXT"
             self.ssl_cafile=None
             self.ssl_certfile=None
             self.ssl_keyfile=None
-        self.logger.info("KafkaConsumer")
-        try:                                                                                                                                                                                                                                                                                                              
+        self.logger.info("KafkaConsumer Instance Creation")
+        try:                
+
             self.consumer=KafkaConsumer(
                           bootstrap_servers=bootstrap_server,   
-                          group_id=groupid,     
+                          group_id=group_id,     
                           value_deserializer=bytes.decode,
                           security_protocol=self.security_protocol,
                           ssl_cafile=self.ssl_cafile,
